"""
Financial Report Parser

一个用于解析财务报表的 Python 包。
"""

__version__ = "0.1.0"
__author__ = "tless"
__email__ = "tlessss@aliyun.com"

# 导入主要的类和函数，让用户可以直接从包名导入
from .parser import FinancialReportParser
from .utils import parse_pdf, extract_text, read_pdf_file

# 定义包的公共 API
__all__ = [
    "FinancialReportParser",
    "parse_pdf",
    "extract_text", 
    "read_pdf_file",
]